@@ -4,8 +4,15 @@ from .utils.files import load_vocab
 from .utils.files import load_shared_vocab
 from .utils.files import count_lines
 from .utils.files import load_sparse
+from .utils.files import load_dense
 from .utils.files import save_sparse
+from .utils.files import save_dense
 from .utils.files import save_vocab
+from .utils.data import load_dataset
+from .utils.metrix import similarity
+from .utils.metrix import spearman
+from .utils.metrix import pearson
+from .utils.metrix import rmse
 from .core.reducer import _reduce_dense as reduce_dense
 from .core.reducer import _get_shared_vocab as get_shared_vocab
 from .core.reducer import _reduce_sparse as reduce_sparse
